#
# spec file for package maven-surefire-plugins
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name maven-surefire
Name:           %{base_name}-plugins
Version:        2.22.2
Release:        150200.3.9.9.1
Summary:        Test framework project
License:        Apache-2.0 AND CPL-1.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/surefire/
Source0:        %{base_name}-%{version}.tar.xz
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Source2:        https://www.eclipse.org/legal/cpl-v10.html
Patch0:         0001-Maven-3.patch
Patch1:         0002-Port-to-current-doxia.patch
Patch2:         0003-Port-to-TestNG-7.4.0.patch
Patch3:         0004-Port-to-current-maven-shared-utils.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-site-renderer)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven.surefire:maven-surefire-common)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-logger-api)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-report-parser)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
BuildArch:      noarch

%description
Surefire is a test framework project.

%package -n maven-surefire-plugin
Summary:        Surefire plugin for maven
Group:          Development/Libraries/Java

%description -n maven-surefire-plugin
Maven surefire plugin for running tests via the surefire framework.

%package -n maven-surefire-report-plugin
Summary:        Surefire reports plugin for maven
Group:          Development/Libraries/Java

%description -n maven-surefire-report-plugin
Plugin for generating reports from surefire test runs.

%package -n maven-failsafe-plugin
Summary:        Maven plugin for running integration tests
Group:          Development/Libraries/Java

%description -n maven-failsafe-plugin
The Failsafe Plugin is designed to run integration tests while the
Surefire Plugins is designed to run unit. The name (failsafe) was
chosen both because it is a synonym of surefire and because it implies
that when it fails, it does so in a safe way.

If you use the Surefire Plugin for running tests, then when you have a
test failure, the build will stop at the integration-test phase and
your integration test environment will not have been torn down
correctly.

The Failsafe Plugin is used during the integration-test and verify
phases of the build lifecycle to execute the integration tests of an
application. The Failsafe Plugin will not fail the build during the
integration-test phase thus enabling the post-integration-test phase
to execute.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{base_name}-%{version}
cp -p %{SOURCE1} %{SOURCE2} .

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

# Disable strict doclint
sed -i /-Xdoclint:all/d pom.xml

%pom_remove_dep -r org.apache.maven.surefire:surefire-shadefire

# QA plugin useful only for upstream
%pom_remove_plugin -r :jacoco-maven-plugin

# Not in Fedora
%pom_remove_plugin -r :animal-sniffer-maven-plugin
# Complains
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
# We don't need site-source
%pom_remove_plugin :maven-assembly-plugin maven-surefire-plugin
%pom_remove_dep -r ::::site-source

%pom_xpath_set pom:mavenVersion 3.3.3
%pom_remove_dep :maven-project maven-surefire-report-plugin
%pom_remove_dep :maven-project maven-surefire-common
%pom_remove_dep :maven-plugin-descriptor maven-surefire-common
%pom_remove_dep :maven-toolchain maven-surefire-common

%pom_xpath_remove -r "pom:execution[pom:id='shared-logging-generated-sources']"

%pom_add_dep com.google.code.findbugs:jsr305 surefire-api

%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r :build-helper-maven-plugin
find . -name dependency-reduced-pom.xml -delete

%pom_add_dep org.apache.commons:commons-lang3::runtime maven-surefire-plugin
%pom_add_dep commons-io:commons-io::runtime maven-surefire-plugin

%pom_xpath_inject pom:project/pom:properties "
    <mavenPluginToolsVersion>3.5.2</mavenPluginToolsVersion>"

# Disable all modules besides the 3 plugins
for module in \
    surefire-logger-api \
    surefire-api \
    surefire-shadefire \
    surefire-booter \
    surefire-grouper \
    surefire-providers \
    maven-surefire-common \
    surefire-report-parser \
    surefire-its; do
  %pom_disable_module ${module}
done

%build
%{mvn_package} ":*tests*" __noinstall
%{mvn_package} ":{surefire,surefire-providers}" __noinstall
%{mvn_package} ":*{surefire-plugin,report-plugin}*" @1
%{mvn_package} ":*junit-platform*" junit5
%{mvn_package} ":*{junit,testng,failsafe-plugin,report-parser}*"  @1

%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -n maven-surefire-plugin -f .mfiles-surefire-plugin

%files -n maven-surefire-report-plugin -f .mfiles-report-plugin

%files -n maven-failsafe-plugin -f .mfiles-failsafe-plugin

%files javadoc -f .mfiles-javadoc
%license LICENSE-2.0.txt cpl-v10.html

%changelog
* Thu Feb 22 2024 fstrba@suse.com
- Upgrade to 2.22.2
  * Bugs:
    + SUREFIRE-1614: JUnit Runner that writes to System.out
    corrupts Surefire’s STDOUT when using JUnit’s Vintage Engine
- Upgrade to 2.22.1
  * Bugs:
    + SUREFIRE-1532: MIME type for javascript is now officially
    application/javascript
    + SUREFIRE-1535: Surefire unable to run testng suites in
    parallel
    + SUREFIRE-1538: Git considers PNG files as changed although
    there is no change
    + SUREFIRE-1550: The surefire XSD published on maven site lacks
    of some rerun element
    + SUREFIRE-1559: XML Report elements rerunError, rerunFailure,
    flakyFailure, flakyError should contain element stackTrace and
    should not be simpleContent.
    + SUREFIRE-1561: Logs in Parallel Tests are mixed up when
    forkMode=never or forkCount=0
    + SUREFIRE-1564: Can’t override platform version through
    project/plugin dependencies
    + SUREFIRE-1579: Forks mixed up characters in standard output
  * Improvements:
    + SUREFIRE-1552: Nil element “failureMessage” in
    failsafe-summary.xml should have self closed tag
    + SUREFIRE-1554: Fix old test resources TEST-*.xml in favor of
    continuing with SUREFIRE-1550
    + SUREFIRE-1555: Elapsed time in XML Report should satisfy
    pattern in XSD.
    + SUREFIRE-1562: Support Java 11
    + SUREFIRE-1565: Surefire should support parameterized
    reportsDirectory
  * Tasks:
    + SUREFIRE-1569: m-invoker-p:3.1.0 attempts to resolve
    maven-surefire-common:jar:2.22.1-SNAPSHOT from remote repo
    'apache.snapshots'
    + SUREFIRE-1578: Remove obsolete module
    surefire-setup-integration-tests
  * Dependency upgrades:
    + SUREFIRE-1540: Upgrade maven-plugins parent to version 32
    + SUREFIRE-1571: Upgrade maven-plugins parent to version 33
- Fetch sources using source service to avoid bundling binaries in
  sources
- Fix broken links in the spec file
- Modified patch:
  * 0004-Port-to-current-maven-shared-utils.patch
    + rediff to changed context
* Thu May  5 2022 fstrba@suse.com
- Clean and simplify the spec file in order to be able to generate
  the javadoc with either maven-javadoc-plugin or xmvn javadoc mojo
* Wed Apr 27 2022 fstrba@suse.com
- Modified patches:
  * 0004-Port-to-current-maven-shared-utils.patch
    + Add some try/catch blocks so that we catch new exceptions
    potentially thrown by maven-shared-utils-3.3.x
  * 0003-Port-to-TestNG-6.11.patch -> 0003-Port-to-TestNG-7.4.0.patch
    + Allow building with the new testng 7.4.0
* Tue Mar 22 2022 fstrba@suse.com
- Build with source and target level 8
* Mon Apr 19 2021 pmonreal@suse.com
- Update generate-tarball.sh to use https URL [bsc#1182708]
* Sun Nov 24 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Apr  3 2019 fstrba@suse.com
- Initial packaging of the non-bootstrap versions of maven plugins
  distributed with surefire 2.22.0
